from kfk.command import kfk
from kfk.clusters_command import clusters
from kfk.topics_command import topics
from kfk.users_command import users
from kfk.console_command import console_consumer, console_producer
from kfk.configs_command import configs
from kfk.version_command import version
from kfk.acls_command import acls
from kfk.setup import setup


setup()